/*!

    Copyright 2011 Michael Phan-Ba

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

 */

/** Module dependencies. */

var vows = require('vows')
  , assert = require('assert');

var connector = require('../../lib/connector')
  , merge = connector.merge;

/** Vows tests. */

vows.describe('util').addBatch({
  'merge()': {
    topic: function() {
      return {
        foo: 'bar',
        pass: 'xyzzy'
      };
    },
    'should return the target': function(fixture) {
      var target = {}
      assert.strictEqual(merge(target, fixture), target);
    },
    'should copy keys to the target': function(fixture) {
      assert.deepEqual(merge({}, fixture), fixture);
    },
    'should prioritize latter source keys': function(fixture) {
      assert.deepEqual(merge({}, fixture, { foo: 'baz' }),
                      { foo: 'baz', pass: 'xyzzy' });
      assert.deepEqual(merge({}, fixture, { foo: 'baz' }, { pass: 'password' }),
                      { foo: 'baz', pass: 'password' });
    }
  }
}).export(module);
